summaryrefslogtreecommitdiff
path: root/lib/chef/provider.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/chef/provider.rb')
-rw-r--r--lib/chef/provider.rb10
1 files changed, 2 insertions, 8 deletions
diff --git a/lib/chef/provider.rb b/lib/chef/provider.rb
index d933164c8c..680fe9782f 100644
--- a/lib/chef/provider.rb
+++ b/lib/chef/provider.rb
@@ -33,12 +33,6 @@ class Chef
extend Chef::Mixin::DescendantsTracker
class << self
- attr_accessor :replace_classes
-
- def replace_classes
- @replace_classes ||= []
- end
-
def node_map
@node_map ||= Chef::NodeMap.new
end
@@ -52,8 +46,8 @@ class Chef
node_map.get(node, resource.resource_name)
end
- # handles the given resource and action (late binding)
- def handles?(resource, action)
+ # supports the given resource and action (late binding)
+ def supports?(resource, action)
true
end
end